@@ -3,9 +3,9 @@ use warnings;
 use strict;
 
 # Copyright 2004 Randy Smith
-# $Id: ExtHandler.pm,v 1.50 2007/09/20 18:01:51 perlstalker Exp $
+# $Id: ExtHandler.pm,v 1.51 2007/09/24 20:16:06 perlstalker Exp $
 
-our $REVISION = (split (' ', '$Revision: 1.50 $'))[1];
+our $REVISION = (split (' ', '$Revision: 1.51 $'))[1];
 our $VERSION = "0.3.2";
 
 use lib qw(..);
@@ -647,7 +647,9 @@ sub run_tasks
 		# and push any ::ResultSets on to the result list.
 		foreach my $r (@$rs) {
 		    if (UNIVERSAL::isa($r, "VUser::ResultSet")) {
-			push @results, $rs;
+			push @results, $r;
+		    } elsif (UNIVERSAL::isa($r, 'ARRAY')) {
+			push @results, $r;
 		    }
 		}
 	    }
